==> 0.1.41.tar.gz: lib/widgets/responsive_layout.dart <==
import 'package:flutter/material.dart';

class ResponsiveLayout extends StatelessWidget {
  final Widget tiny;
  final Widget phone;
  final Widget tablet;
  final Widget largeTablet;
  final Widget? largeTablet1;
  final Widget? largeTablet2;
  final Widget? computerSmall;
  final Widget computer;

  const ResponsiveLayout({
    required this.tiny,
    required this.phone,
    required this.tablet,
    required this.largeTablet,
    this.largeTablet1,
    this.largeTablet2,
    this.computerSmall,
    required this.computer,
  });

  static final int tinyHeightLimit = 100;
  static final int tinyLimit = 270;
  static final int phoneLimit = 550;
  static final int tabletLimit = 800;
  static final int largeTabletLimit = 1100;
  static final int largeTabletLimit1 = 950;
  static final int largeTabletLimit2 = 1100;
  static final int computerSmallLimit1 = 1350;
  static final int computerSmallLimit2 = 1520;

  static bool isTinyHeightLimit(BuildContext context) =>
      MediaQuery.of(context).size.height < tinyHeightLimit;

  static bool isTinyLimit(BuildContext context) =>
      MediaQuery.of(context).size.width < tinyLimit;

  static bool isPhone(BuildContext context) =>
      MediaQuery.of(context).size.width < phoneLimit &&
      MediaQuery.of(context).size.width >= tinyLimit;

  static bool isTablet(BuildContext context) =>
      MediaQuery.of(context).size.width < tabletLimit &&
      MediaQuery.of(context).size.width >= phoneLimit;

  static bool isLargeTablet(BuildContext context) =>
      MediaQuery.of(context).size.width < largeTabletLimit &&
      MediaQuery.of(context).size.width >= tabletLimit;

  static bool isComputer(BuildContext context) =>
      MediaQuery.of(context).size.width >= largeTabletLimit;

  static bool isComputerSmall(BuildContext context) =>
      MediaQuery.of(context).size.width < computerSmallLimit1 &&
      MediaQuery.of(context).size.width >= largeTabletLimit;

  static bool isComputerSmall2(BuildContext context) =>
      MediaQuery.of(context).size.width < computerSmallLimit2 &&
      MediaQuery.of(context).size.width >= computerSmallLimit1;

  static dynamic byWidth(context, size,
      {computer,
      computerSmall2,
      computerSmall,
      largeTablet,
      tablet,
      phone,
      tiny}) {
    if (isComputerSmall2(context)) return computerSmall2 ?? size;
    if (isComputerSmall(context)) return computerSmall ?? size;
    if (isComputer(context)) return computer ?? size;
    if (isLargeTablet(context)) return largeTablet ?? size;
    if (isTablet(context)) return tablet ?? size;
    if (isPhone(context)) return phone ?? size;
    if (isTinyLimit(context)) return tiny ?? size;
    return size;
  }

  static dynamic byWidth2(context, size,
      [computerSmall2, computerSmall, largeTablet, tablet, phone, tiny]) {
    if (isComputerSmall2(context)) return computerSmall2 ?? size;
    if (isComputerSmall(context)) return computerSmall ?? size;
    if (isComputer(context)) return size;
    if (isLargeTablet(context)) return largeTablet ?? size;
    if (isTablet(context)) return tablet ?? size;
    if (isPhone(context)) return phone ?? size;
    if (isTinyLimit(context)) return tiny ?? size;
    return size;
  }

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (BuildContext context, BoxConstraints constraints) {
        print('constraints.maxWidth: ${constraints.maxWidth}');
        if (constraints.maxWidth < tinyLimit ||
            constraints.maxHeight < tinyHeightLimit) {
          return tiny;
        }
        if (constraints.maxWidth < phoneLimit) {
          return phone;
        }
        if (constraints.maxWidth < tabletLimit) {
          return tablet;
        }
        if (constraints.maxWidth < largeTabletLimit1 && largeTablet1 != null) {
          return largeTablet1!;
        }
        if (constraints.maxWidth < largeTabletLimit2 && largeTablet2 != null) {
          return largeTablet2!;
        }
        if (constraints.maxWidth < largeTabletLimit) {
          return largeTablet;
        } else if (constraints.maxWidth < computerSmallLimit1 &&
            computerSmall != null) {
          return computerSmall!;
        } else {
          return computer;
        }
      },
    );
  }
}

==> 0.1.47.tar.gz: lib/widgets/responsive_layout.dart <==
import 'package:flutter/material.dart';
import 'package:oowoo_core/utils/utils.dart';

class ResponsiveLayout extends StatelessWidget {
  final Widget tiny;
  final Widget phone;
  final Widget tablet;
  final Widget largeTablet;
  final Widget? largeTablet1;
  final Widget? largeTablet2;
  final Widget? computerSmall;
  final Widget computer;

  const ResponsiveLayout({
    super.key,
    required this.tiny,
    required this.phone,
    required this.tablet,
    required this.largeTablet,
    this.largeTablet1,
    this.largeTablet2,
    this.computerSmall,
    required this.computer,
  });

  static const int tinyHeightLimit = 100;
  static const int tinyLimit = 270;
  static const int phoneLimit = 550;
  static const int tabletLimit = 800;
  static const int largeTabletLimit = 1100;
  static const int largeTabletLimit1 = 950;
  static const int largeTabletLimit2 = 1100;
  static const int computerSmallLimit1 = 1350;
  static const int computerSmallLimit2 = 1520;

  static bool isTinyHeightLimit(BuildContext context) =>
      MediaQuery.of(context).size.height < tinyHeightLimit;

  static bool isTinyLimit(BuildContext context) =>
      MediaQuery.of(context).size.width < tinyLimit;

  static bool isPhone(BuildContext context) =>
      MediaQuery.of(context).size.width < phoneLimit &&
      MediaQuery.of(context).size.width >= tinyLimit;

  static bool isTablet(BuildContext context) =>
      MediaQuery.of(context).size.width < tabletLimit &&
      MediaQuery.of(context).size.width >= phoneLimit;

  static bool isLargeTablet(BuildContext context) =>
      MediaQuery.of(context).size.width < largeTabletLimit &&
      MediaQuery.of(context).size.width >= tabletLimit;

  static bool isComputer(BuildContext context) =>
      MediaQuery.of(context).size.width >= largeTabletLimit;

  static bool isComputerSmall(BuildContext context) =>
      MediaQuery.of(context).size.width < computerSmallLimit1 &&
      MediaQuery.of(context).size.width >= largeTabletLimit;

  static bool isComputerSmall2(BuildContext context) =>
      MediaQuery.of(context).size.width < computerSmallLimit2 &&
      MediaQuery.of(context).size.width >= computerSmallLimit1;

  static T byWidth<T>(context, T size,
      {T? computer,
      T? computerSmall2,
      T? computerSmall,
      T? largeTablet,
      T? tablet,
      T? phone,
      T? tiny}) {
    if (isComputerSmall2(context)) return computerSmall2 ?? size;
    if (isComputerSmall(context)) return computerSmall ?? size;
    if (isComputer(context)) return computer ?? size;
    if (isLargeTablet(context)) return largeTablet ?? size;
    if (isTablet(context)) return tablet ?? size;
    if (isPhone(context)) return phone ?? size;
    if (isTinyLimit(context)) return tiny ?? size;
    return size;
  }

  static T byWidth2<T>(context, T size,
      [T? computerSmall2,
      T? computerSmall,
      T? largeTablet,
      T? tablet,
      T? phone,
      T? tiny]) {
    if (isComputerSmall2(context)) return computerSmall2 ?? size;
    if (isComputerSmall(context)) return computerSmall ?? size;
    if (isComputer(context)) return size;
    if (isLargeTablet(context)) return largeTablet ?? size;
    if (isTablet(context)) return tablet ?? size;
    if (isPhone(context)) return phone ?? size;
    if (isTinyLimit(context)) return tiny ?? size;
    return size;
  }

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (BuildContext context, BoxConstraints constraints) {
        appDebugPrint('constraints.maxWidth: ${constraints.maxWidth}');
        if (constraints.maxWidth < tinyLimit ||
            constraints.maxHeight < tinyHeightLimit) {
          return tiny;
        }
        if (constraints.maxWidth < phoneLimit) {
          return phone;
        }
        if (constraints.maxWidth < tabletLimit) {
          return tablet;
        }
        if (constraints.maxWidth < largeTabletLimit1 && largeTablet1 != null) {
          return largeTablet1!;
        }
        if (constraints.maxWidth < largeTabletLimit2 && largeTablet2 != null) {
          return largeTablet2!;
        }
        if (constraints.maxWidth < largeTabletLimit) {
          return largeTablet;
        } else if (constraints.maxWidth < computerSmallLimit1 &&
            computerSmall != null) {
          return computerSmall!;
        } else {
          return computer;
        }
      },
    );
  }
}
